@@ -89,7 +89,11 @@ KFountainSetup::KFountainSetup( QWidget *parent )
 
 	//preview = new QWidget( this );
 	preview->setFixedSize( 220, 170 );
-	preview->setBackgroundColor( Qt::black );
+        {
+            QPalette palette;
+            palette.setColor( preview->backgroundRole(), Qt::black );
+            preview->setPalette( palette );
+        }
 	preview->show();    // otherwise saver does not get correct size
 	saver = new KFountainSaver( preview->winId() );
 	//tl1->addWidget(preview);
@@ -133,11 +137,11 @@ void KFountainSetup::slotOkPressed()
 	KConfig _config("kssfountainrc", KConfig::NoGlobals);
 	KConfigGroup config(&_config, "Settings" );
 
-	if (RadioButton1->isOn() == true)
+	if (RadioButton1->isChecked() == true)
 	{
 		config.writeEntry( "Stars", "true" );
 	} else {
-		if (RadioButton1_2->isOn() == true)
+		if (RadioButton1_2->isChecked() == true)
 		{
 			config.writeEntry( "Stars", "false" );
 		}
@@ -163,9 +167,13 @@ KFountainSaver::KFountainSaver( WId id ) : KScreenSaver( id )
 	kDebug() << "Blank";
 
 	timer = new QTimer( this );
-        timer->setSingleShot(true);
-        timer->start( 25);
-	setBackgroundColor( Qt::black );
+        timer->setSingleShot( true );
+        timer->start( 25 );
+        {
+            QPalette palette;
+            palette.setColor( backgroundRole(), Qt::black );
+            setPalette( palette );
+        }
         update();
 	fountain = new Fountain();
 	embed(fountain);
@@ -236,30 +244,30 @@ bool Fountain::loadParticle()
     QImage buf;
 
     kDebug() << "Loading: " << KStandardDirs::locate("data", "kscreensaver/particle.png");
- if (buf.load( KStandardDirs::locate("data", "kscreensaver/particle.png") ) )
 
-        {
-		tex = convertToGLFormat(buf);  // flipped 32bit RGBA
-		kDebug() << "Texture loaded: " << tex.numBytes ();
-	}
-	else
-	{
-		QImage dummy( 32, 32, 32 );
-  		dummy.fill( Qt::white );
-        	buf = dummy;
-		tex = convertToGLFormat( buf );
-	}
+    if (buf.load( KStandardDirs::locate("data", "kscreensaver/particle.png") ) )
+    {
+        tex = convertToGLFormat(buf);  // flipped 32bit RGBA
+        kDebug() << "Texture loaded: " << tex.numBytes ();
+    }
+    else
+    {
+        QImage dummy( 32, 32, QImage::Format_RGB32 );
+        dummy.fill( Qt::white );
+        buf = dummy;
+        tex = convertToGLFormat( buf );
+    }
 
-            /* Set the status to true */
-            //Status = true;
-	glGenTextures(1, &texture[0]);   /* create three textures */
-	glBindTexture(GL_TEXTURE_2D, texture[0]);
-	/* use linear filtering */
-	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-	/* actually generate the texture */
-	glTexImage2D(GL_TEXTURE_2D, 0, 4, tex.width(), tex.height(), 0,
-	GL_RGBA, GL_UNSIGNED_BYTE, tex.bits());
+    /* Set the status to true */
+    //Status = true;
+    glGenTextures(1, &texture[0]);   /* create three textures */
+    glBindTexture(GL_TEXTURE_2D, texture[0]);
+    /* use linear filtering */
+    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+    /* actually generate the texture */
+    glTexImage2D(GL_TEXTURE_2D, 0, 4, tex.width(), tex.height(), 0,
+    GL_RGBA, GL_UNSIGNED_BYTE, tex.bits());
 
 
 
